﻿#!/usr/bin/python
# -*- coding: utf-8 -*-

import re

class QonsoModel:
   def __init__(self):
      self.lastTime = ""
      self.voix = dict(int=0, str="0 min")
      self.voixMax = dict(int=0, str="0 min")
      self.data = ""
      self.dataMax = 0
      self.hforfait = ""
      self.facture = "Prochaine facture : "
      self.sms = ""
      self.report = dict(int=0, str="Pas de minutes report&eacute;es ce mois ci")
      self.regHM = "(\d+)*?\s*[Hh]?\s*(\d\d\d*)"

   def GetLastTime(self):
      return self.lastTime

   def GetForfait(self):
      return "Neo.3 illimite de 21h30 a 8h"

   def ExtractTime(self, s):
      res = re.search(self.regHM, s)
      timenum = 0
      timestr = "0 min"

      if res:
         h = 0
         if res.group(1):
            h = int(res.group(1))
         m = int(res.group(2))
         timenum = h*60+m
         h = int(timenum/60)
         m = timenum-h*60

         timestr = ""
         if h>=1:
            timestr = str(h)+"h"
         timestr = "%s%.2d min"%(timestr, m)
      
      return timenum, timestr
      
   ## 
   # Remplit les données pour la consommation voix
   # @param s  string contenant les données au format [hh]h[mm] (ex : 2h 30)
   def SetConsoVoix(self, s):
      self.voix['int'], self.voix['str'] = self.ExtractTime(s)
   
   ##
   # Renvoit la consommation voix, en fonction du type
   # @param type  string prenant comme valeur 'int' ou 'str'
   # @return  consommation voix en minutes (int), ou au format 2h30 (str)
   def GetConsoVoix(self, type):
      return self.voix[type]

   ## 
   # Remplit la durée du forfait pour la consommation voix
   # @param s  string contenant les données au format [hh]h[mm] (ex : 2h 30)
   def SetConsoVoixMax(self, s):
      self.voixMax['int'], self.voixMax['str'] = self.ExtractTime(s)

   ##
   # Renvoit la durée du forfait pour la consommation voix, en fonction du type
   # @param type  string prenant comme valeur 'int' ou 'str'
   # @return  consommation voix en minutes (int), ou au format 2h30 (str)
   def GetConsoVoixMax(self, type):
      return self.voixMax[type]

   ## 
   # Remplit les données pour la consommation data (internet)
   # @param s  string contenant la taille des données sous forme numérique (example : 110)
   def GetConsoData(self):
      if self.data:
         return self.data.simplified().replace("Mo", "").toFloat()[0]
      else:
         return 0

   ##
   # Renvoit la taille du forfait data
   # @return  consommation data en Mo
   def GetConsoDataMax(self):
      return self.dataMax

   ##
   # Renvoit le nombre de SMS émis
   # @return  nombre de SMS
   def GetConsoSMS(self):
      return self.sms

   ##
   # Renvoit le montant de la consommation hors forfait
   # @return  consommation hors forfait en Euros
   def GetConsoHorsForfait(self):
      return self.hforfait

   def GetDateProchaineFacture(self):
      return self.facture 
      
   ## 
   # Remplit la durée des minutes reportées
   # @param s  string contenant les données au format [hh]h[mm] (ex : 2h 30)
   def SetReport(self, s):
      self.report['int'], sreport = self.ExtractTime(s)

      if self.report['int'] == 0:
         self.report['str'] = "Pas de minutes report&eacute;es ce mois ci"
      else:
         self.report['str'] = "Report de minutes : "+sreport
      
   ##
   # Renvoit la durée des minutes reportées, en fonction du type
   # @param type  string prenant comme valeur 'int' ou 'str'
   # @return  consommation voix en minutes (int), ou au format 2h30 (str)      
   def GetReport(self, type):
      return self.report[type]
